==> graphql-web-lite-16.6.0-2.tgz: package/utilities/coerceInputValue.js <==
var jsutils_didYouMean = require("../jsutils/didYouMean.js");

var jsutils_inspect = require("../jsutils/inspect.js");

var jsutils_invariant = require("../jsutils/invariant.js");

var jsutils_isIterableObject = require("../jsutils/isIterableObject.js");

var jsutils_isObjectLike = require("../jsutils/isObjectLike.js");

var jsutils_Path = require("../jsutils/Path.js");

var jsutils_printPathArray = require("../jsutils/printPathArray.js");

var jsutils_suggestionList = require("../jsutils/suggestionList.js");

var type_definition = require("../type/definition.js");

var shared = require("../shared.js");

function defaultOnError(path, invalidValue, error) {
  let errorPrefix = "Invalid value " + jsutils_inspect.inspect(invalidValue);
  if (path.length > 0) {
    errorPrefix += ` at "value${jsutils_printPathArray.printPathArray(path)}"`;
  }
  error.message = errorPrefix + ": " + error.message;
  throw error;
}

function coerceInputValueImpl(inputValue, type, onError, path) {
  if (type_definition.isNonNullType(type)) {
    if (null != inputValue) {
      return coerceInputValueImpl(inputValue, type.ofType, onError, path);
    }
    onError(jsutils_Path.pathToArray(path), inputValue, new shared.GraphQLError(`Expected non-nullable type "${jsutils_inspect.inspect(type)}" not to be null.`));
    return;
  }
  if (null == inputValue) {
    return null;
  }
  if (type_definition.isListType(type)) {
    const itemType = type.ofType;
    if (jsutils_isIterableObject.isIterableObject(inputValue)) {
      return Array.from(inputValue, ((itemValue, index) => {
        const itemPath = jsutils_Path.addPath(path, index, void 0);
        return coerceInputValueImpl(itemValue, itemType, onError, itemPath);
      }));
    }
    return [ coerceInputValueImpl(inputValue, itemType, onError, path) ];
  }
  if (type_definition.isInputObjectType(type)) {
    if (!jsutils_isObjectLike.isObjectLike(inputValue)) {
      onError(jsutils_Path.pathToArray(path), inputValue, new shared.GraphQLError(`Expected type "${type.name}" to be an object.`));
      return;
    }
    const coercedValue = {};
    const fieldDefs = type.getFields();
    for (const field of Object.values(fieldDefs)) {
      const fieldValue = inputValue[field.name];
      if (void 0 === fieldValue) {
        if (void 0 !== field.defaultValue) {
          coercedValue[field.name] = field.defaultValue;
        } else if (type_definition.isNonNullType(field.type)) {
          const typeStr = jsutils_inspect.inspect(field.type);
          onError(jsutils_Path.pathToArray(path), inputValue, new shared.GraphQLError(`Field "${field.name}" of required type "${typeStr}" was not provided.`));
        }
        continue;
      }
      coercedValue[field.name] = coerceInputValueImpl(fieldValue, field.type, onError, jsutils_Path.addPath(path, field.name, type.name));
    }
    for (const fieldName of Object.keys(inputValue)) {
      if (!fieldDefs[fieldName]) {
        const suggestions = jsutils_suggestionList.suggestionList(fieldName, Object.keys(type.getFields()));
        onError(jsutils_Path.pathToArray(path), inputValue, new shared.GraphQLError(`Field "${fieldName}" is not defined by type "${type.name}".` + jsutils_didYouMean.didYouMean(suggestions)));
      }
    }
    return coercedValue;
  }
  if (type_definition.isLeafType(type)) {
    let parseResult;
    try {
      parseResult = type.parseValue(inputValue);
    } catch (error) {
      if (error instanceof shared.GraphQLError) {
        onError(jsutils_Path.pathToArray(path), inputValue, error);
      } else {
        onError(jsutils_Path.pathToArray(path), inputValue, new shared.GraphQLError(`Expected type "${type.name}". ` + error.message, {
          originalError: error
        }));
      }
      return;
    }
    if (void 0 === parseResult) {
      onError(jsutils_Path.pathToArray(path), inputValue, new shared.GraphQLError(`Expected type "${type.name}".`));
    }
    return parseResult;
  }
  jsutils_invariant.invariant(!1);
}

exports.coerceInputValue = function coerceInputValue(inputValue, type, onError = defaultOnError) {
  return coerceInputValueImpl(inputValue, type, onError, void 0);
};

==> graphql-web-lite-16.6.0-4.tgz: package/utilities/coerceInputValue.js <==
var jsutils_didYouMean = require("../jsutils/didYouMean.js");

var jsutils_inspect = require("../jsutils/inspect.js");

var jsutils_invariant = require("../jsutils/invariant.js");

var jsutils_isIterableObject = require("../jsutils/isIterableObject.js");

var jsutils_isObjectLike = require("../jsutils/isObjectLike.js");

var jsutils_Path = require("../jsutils/Path.js");

var jsutils_printPathArray = require("../jsutils/printPathArray.js");

var jsutils_suggestionList = require("../jsutils/suggestionList.js");

var type_definition = require("../type/definition.js");

var graphql_web = require("@0no-co/graphql.web");

function defaultOnError(path, invalidValue, error) {
  let errorPrefix = "Invalid value " + jsutils_inspect.inspect(invalidValue);
  if (path.length > 0) {
    errorPrefix += ` at "value${jsutils_printPathArray.printPathArray(path)}"`;
  }
  error.message = errorPrefix + ": " + error.message;
  throw error;
}

function coerceInputValueImpl(inputValue, type, onError, path) {
  if (type_definition.isNonNullType(type)) {
    if (null != inputValue) {
      return coerceInputValueImpl(inputValue, type.ofType, onError, path);
    }
    onError(jsutils_Path.pathToArray(path), inputValue, new graphql_web.GraphQLError(`Expected non-nullable type "${jsutils_inspect.inspect(type)}" not to be null.`));
    return;
  }
  if (null == inputValue) {
    return null;
  }
  if (type_definition.isListType(type)) {
    const itemType = type.ofType;
    if (jsutils_isIterableObject.isIterableObject(inputValue)) {
      return Array.from(inputValue, ((itemValue, index) => {
        const itemPath = jsutils_Path.addPath(path, index, void 0);
        return coerceInputValueImpl(itemValue, itemType, onError, itemPath);
      }));
    }
    return [ coerceInputValueImpl(inputValue, itemType, onError, path) ];
  }
  if (type_definition.isInputObjectType(type)) {
    if (!jsutils_isObjectLike.isObjectLike(inputValue)) {
      onError(jsutils_Path.pathToArray(path), inputValue, new graphql_web.GraphQLError(`Expected type "${type.name}" to be an object.`));
      return;
    }
    const coercedValue = {};
    const fieldDefs = type.getFields();
    for (const field of Object.values(fieldDefs)) {
      const fieldValue = inputValue[field.name];
      if (void 0 === fieldValue) {
        if (void 0 !== field.defaultValue) {
          coercedValue[field.name] = field.defaultValue;
        } else if (type_definition.isNonNullType(field.type)) {
          const typeStr = jsutils_inspect.inspect(field.type);
          onError(jsutils_Path.pathToArray(path), inputValue, new graphql_web.GraphQLError(`Field "${field.name}" of required type "${typeStr}" was not provided.`));
        }
        continue;
      }
      coercedValue[field.name] = coerceInputValueImpl(fieldValue, field.type, onError, jsutils_Path.addPath(path, field.name, type.name));
    }
    for (const fieldName of Object.keys(inputValue)) {
      if (!fieldDefs[fieldName]) {
        const suggestions = jsutils_suggestionList.suggestionList(fieldName, Object.keys(type.getFields()));
        onError(jsutils_Path.pathToArray(path), inputValue, new graphql_web.GraphQLError(`Field "${fieldName}" is not defined by type "${type.name}".` + jsutils_didYouMean.didYouMean(suggestions)));
      }
    }
    return coercedValue;
  }
  if (type_definition.isLeafType(type)) {
    let parseResult;
    try {
      parseResult = type.parseValue(inputValue);
    } catch (error) {
      if (error instanceof graphql_web.GraphQLError) {
        onError(jsutils_Path.pathToArray(path), inputValue, error);
      } else {
        onError(jsutils_Path.pathToArray(path), inputValue, new graphql_web.GraphQLError(`Expected type "${type.name}". ` + error.message, {
          originalError: error
        }));
      }
      return;
    }
    if (void 0 === parseResult) {
      onError(jsutils_Path.pathToArray(path), inputValue, new graphql_web.GraphQLError(`Expected type "${type.name}".`));
    }
    return parseResult;
  }
  jsutils_invariant.invariant(!1);
}

exports.coerceInputValue = function coerceInputValue(inputValue, type, onError = defaultOnError) {
  return coerceInputValueImpl(inputValue, type, onError, void 0);
};
